@@ -13,19 +13,19 @@ use Class::XSAccessor
   getters => {
     map { $_ => $_; }
         qw(
-          broadColumn
-          broadHeader
-          broadRow
+          broad_column
+          broad_header
+          broad_row
           collapse
-          columnWidth
-          currentRow
-          endOfTable
+          column_width
+          current_row
+          end_of_table
           header
           pad
-          pageHeight
+          page_height
           rows
-          separateRows
-          tableWidth
+          separate_rows
+          table_width
         )
   };
 
@@ -54,131 +54,131 @@ use constant {                                              # Integer that hopef
 };
 use constant {                                              # Valid option combinations in form required by
   ALL_OPTIONS => {                                          # Params::Validate::validate
-    header       => {
-      default     => [],
-      optional    => 1,
+    header        => {
+      default      => [],
+      optional     => 1,
     },
-    rows         => {
-      default     => [],
-      optional    => 1,
+    rows          => {
+      default      => [],
+      optional     => 1,
     },
-    broadColumn  => {
-      default     => [WRAP],
-      optional    => 1,
+    broad_column  => {
+      default      => [WRAP],
+      optional     => 1,
     },
-    broadHeader  => {
-      default     => [WRAP],
-      optional    => 1,
+    broad_header  => {
+      default      => [WRAP],
+      optional     => 1,
     },
-    broadRow     => {
-      default     => WRAP,
-      optional    => 1,
+    broad_row     => {
+      default      => WRAP,
+      optional     => 1,
     },
-    collapse     => {
-      default     => [FALSE],
-      optional    => 1,
+    collapse      => {
+      default      => [FALSE],
+      optional     => 1,
     },
-    columnWidth  => {
-      default     => [ADJUST],
-      optional    => 1,
+    column_width  => {
+      default      => [ADJUST],
+      optional     => 1,
     },
-    pad          => {
-      default     => 1,
-      optional    => 1,
+    pad           => {
+      default      => 1,
+      optional     => 1,
     },
-    pageHeight   => {
-      default     => \&_screenHeight,
-      optional    => 1,
+    page_height   => {
+      default      => \&_screenHeight,
+      optional     => 1,
     },
-    separateRows => {
-      default     => FALSE,
-      optional    => 1,
+    separate_rows => {
+      default      => FALSE,
+      optional     => 1,
     },
-    tableWidth   => {
-      default     => \&_screenWidth,
-      optional    => 1,
+    table_width   => {
+      default      => \&_screenWidth,
+      optional     => 1,
     },
   },
 };
 use constant {
   OPTIONS_ARRAY => {
     %{ALL_OPTIONS()},
-    rows        => {
+    rows         => {
       type        => ARRAYREF,
       callbacks   => {
-        q('rows' element is an array reference)                                   => \&_isEachRowArray,
-        q(all 'rows' elements have same length)                                   => \&_areAllRowsOfEqualLength,
-        q('rows' elements contain defined scalars only)                           => \&_isEachCellScalar,
+        q('rows' element is an array reference)                                    => \&_isEachRowArray,
+        q(all 'rows' elements have same length)                                    => \&_areAllRowsOfEqualLength,
+        q('rows' elements contain defined scalars only)                            => \&_isEachCellScalar,
       },
     },
-    broadRow    => {
+    broad_row    => {
       type        => SCALAR,
       optional    => 1,
-      callbacks   => { q('broadRow' is either 'CUT', or 'SPLIT', or 'WRAP')       => \&_isCutOrSplitOrWrap },
+      callbacks   => { q('broad_row' is either 'CUT', or 'SPLIT', or 'WRAP')       => \&_isCutOrSplitOrWrap },
     },
-    collapse    => {
+    collapse     => {
       type        => ARRAYREF | SCALAR,
       optional    => 1,
     },
-    columnWidth => {
+    column_width => {
       type        => ARRAYREF | SCALAR,
       optional    => 1,
-      callbacks   => { q('columnWidth' is undefined or a positive integer)        => \&_isEachColumnWidthUndefOrInt },
+      callbacks   => { q('column_width' is undefined or a positive integer)        => \&_isEachColumnWidthUndefOrInt },
     },
   },
   OPTIONS_CALLBACK => {
     %{ALL_OPTIONS()},
-    broadRow    => {
+    broad_row   => {
       type        => SCALAR,
       optional    => 1,
-      callbacks   => { q('broadRow' is either 'CUT' or 'WRAP')                    => \&_isCutOrWrap },
+      callbacks   => { q('broad_row' is either 'CUT' or 'WRAP')                    => \&_isCutOrWrap },
     },
-    columnWidth => {
+    column_width => {
       type        => ARRAYREF | SCALAR,
       optional    => 1,
-      callbacks   => { q('columnWidth' is a positive integer)                     => \&_isEachColumnWidthInt },
+      callbacks   => { q('column_width' is a positive integer)                     => \&_isEachColumnWidthInt },
     },
   },
   OPTIONS_GENERAL => {
     %{ALL_OPTIONS()},
-    header       => {
-      type        => ARRAYREF,
-      optional    => 1,
-      callbacks   => { q('header' element is a scalar)                            => \&_isScalar },
+    header        => {
+      type         => ARRAYREF,
+      optional     => 1,
+      callbacks    => { q('header' element is a scalar)                             => \&_isScalar },
     },
-    broadColumn  => {
-      type        => ARRAYREF | SCALAR,
-      optional    => 1,
-      callbacks   => { q('broadColumn' is / contains either 'CUT' or 'WRAP' only) => \&_isEachColumnFlagCutOrWrap },
+    broad_column  => {
+      type         => ARRAYREF | SCALAR,
+      optional     => 1,
+      callbacks    => { q('broad_column' is / contains either 'CUT' or 'WRAP' only) => \&_isEachColumnFlagCutOrWrap },
     },
-    broadHeader  => {
-      type        => ARRAYREF | SCALAR,
-      optional    => 1,
-      callbacks   => { q('broadHeader' is / contains either 'CUT' or 'WRAP' only) => \&_isEachColumnFlagCutOrWrap },
+    broad_header  => {
+      type         => ARRAYREF | SCALAR,
+      optional     => 1,
+      callbacks    => { q('broad_header' is / contains either 'CUT' or 'WRAP' only) => \&_isEachColumnFlagCutOrWrap },
     },
-    columnWidth  => {
-      type        => ARRAYREF | SCALAR,
-      optional    => 1,
-      callbacks   => { q('columnWidth' is a positive integer)                     => \&_isEachColumnWidthInt },
+    column_width  => {
+      type         => ARRAYREF | SCALAR,
+      optional     => 1,
+      callbacks    => { q('column_width' is a positive integer)                     => \&_isEachColumnWidthInt },
     },
-    pad          => {
-      type        => ARRAYREF | SCALAR,
-      optional    => 1,
-      callbacks   => { q('pad' is undefined or a positive integer)                => \&_isUndefOrInt },
+    pad           => {
+      type         => ARRAYREF | SCALAR,
+      optional     => 1,
+      callbacks    => { q('pad' is undefined or a positive integer)                 => \&_isUndefOrInt },
     },
-    pageHeight   => {
-      type        => SCALAR,
-      optional    => 1,
-      callbacks   => { q('pageHeight' is undefined or a positive integer)         => \&_isUndefOrInt },
+    page_height   => {
+      type         => SCALAR,
+      optional     => 1,
+      callbacks    => { q('page_height' is undefined or a positive integer)         => \&_isUndefOrInt },
     },
-    separateRows => {
-      type        => SCALAR,
-      optional    => 1,
+    separate_rows => {
+      type         => SCALAR,
+      optional     => 1,
     },
-    tableWidth   => {
-      type        => SCALAR,
-      optional    => 1,
-      callbacks   => { q('tableWidth' is undefined or a positive integer)         => \&_isUndefOrInt },
+    table_width   => {
+      type         => SCALAR,
+      optional     => 1,
+      callbacks    => { q('table_width' is undefined or a positive integer)         => \&_isUndefOrInt },
     },
   },
 };
@@ -186,12 +186,12 @@ use constant {
 use Exporter qw(import);
 our @EXPORT_OK = qw(ADJUST CUT SPLIT WRAP);
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 sub fetch {                                                 # Provides current line
   my ($self) = @_;
 
-  return if $self->{'endOfTable'} && !@{$self->{':rowLines'}};
+  return if $self->{'end_of_table'} && !@{$self->{':rowLines'}};
 
   $self->_getNextLines() unless @{$self->{':rowLines'}} && $self->{':lineOnPage'};
   $self->{':lineOnPage'}++;
@@ -221,17 +221,17 @@ sub new {                                                   # Instantiate table
       ':headerLines'     => [],                             # One array element per header line
       ':lineFormat'      => '|',                            # Row line format
       ':lineOnPage'      => 0,                              # Line number relative to the current page
-      ':linesPerPage'    => 1,                              # Considers multiple lines per page depending on 'broadRow'
-      ':linesPerRow'     => 1,                              # Considers multiple lines per row depending on 'broadRow'
+      ':linesPerPage'    => 1,                              # Considers multiple lines per page depending on 'broad_row'
+      ':linesPerRow'     => 1,                              # Considers multiple lines per row depending on 'broad_row'
       ':numberOfColumns' => undef,                          # Number of columns as supplied via 'rows' array
-      ':rowBuffer'       => [],                             # Current row
+      ':rowBuffer'       => [],                             # Current row content
       ':rowLines'        => [],                             # One array element per row line
       ':separatingAdded' => FALSE,                          # Separating line is among ':rowLines'
       ':separatingLine'  => '+',                            # Line separating table / header content
       ':splitOffset'     => 0,                              # Horizontal offset from the table left side
       ':totalWidth'      => 0,                              # Table width independently of possible horizontal splitting
-      'currentRow'       => 0,
-      'endOfTable'       => FALSE,                          # End of table in general (end of last chunk)
+      'current_row'      => 0,                              # Order No. of current row
+      'end_of_table'     => FALSE,                          # End of table in general (end of last chunk)
     },
     $class,
   )->_validate(\@params);
@@ -264,12 +264,11 @@ sub _cutOrWrapLine {
 
   $line = substr($line, $self->{':splitOffset'}) if $self->{':splitOffset'};
 
-  my $lineTooLong = length($line) > $self->{'tableWidth'};;
+  my $lineTooLong = length($line) > $self->{'table_width'};
+                                                            # Wrap is required and line is long enough to be wrapped
+  return unpack('(A' . $self->{'table_width'} . ')*', $line) if $self->{'broad_row'} == WRAP && $lineTooLong;
 
-  return unpack('(A' . $self->{'tableWidth'} . ')*', $line) # Wrap is required and line is long enough to be wrapped
-    if $self->{'broadRow'} == WRAP && $lineTooLong;
-
-  return substr($line, 0, $self->{'tableWidth'})            # Wrap is not required and line is too long
+  return substr($line, 0, $self->{'table_width'})           # Wrap is not required and line is too long
     if $lineTooLong;
 
   return $line;                                             # Line is too short for any change
@@ -281,13 +280,13 @@ sub _extractLine {                                          # Extract 1st remain
   my @line;
 
   foreach my $columnNo (0 .. $self->{':numberOfColumns'} - 1) {
-    my $columnWidth   = $self->{'columnWidth'}[$columnNo];
+    my $column_width  = $self->{'column_width'}[$columnNo];
     my $field         = $row->[$columnNo];
 
     $row->[$columnNo] = do {
-      if (length($field) > $columnWidth) {
-        push(@line, substr($field, 0, $columnWidth));
-        $broadFlags->[$columnNo] == CUT ? '' : substr($field, $columnWidth);
+      if (length($field) > $column_width) {
+        push(@line, substr($field, 0, $column_width));
+        $broadFlags->[$columnNo] == CUT ? '' : substr($field, $column_width);
       }
       else {
         push(@line, $field);
@@ -317,19 +316,19 @@ sub _getNextLines {                                         # Provides next line
 
   if (!@{$self->{':rowLines'}} && @{$self->_getNextRow()}) {
     push(@{$self->{':rowLines'}},
-         map { $self->_cutOrWrapLine($_) } @{$self->_prepareRow($self->{':rowBuffer'}, $self->{'broadColumn'})});
+         map { $self->_cutOrWrapLine($_) } @{$self->_prepareRow($self->{':rowBuffer'}, $self->{'broad_column'})});
     $self->{':separatingAdded'} = FALSE;
   }
 
   my $headerAdded;
-  if ((ref($self->{'rows'}) eq 'ARRAY' && $self->{'currentRow'} == 1 || !$self->{':lineOnPage'})
-  &&  !$self->{'endOfTable'}) {
+  if ((ref($self->{'rows'}) eq 'ARRAY' && $self->{'current_row'} == 1 || !$self->{':lineOnPage'})
+  &&  !$self->{'end_of_table'}) {
     unshift(@{$self->{':rowLines'}}, map { $self->_cutOrWrapLine($_) } @{$self->{':headerLines'}});
     $headerAdded = TRUE;
   }
 
   if (($self->{':endOfChunk'}                               # Ends up the table or separates two rows if required
-  ||   $self->{'separateRows'} && $self->{':lineOnPage'} + @{$self->{':rowLines'}} < $self->{'pageHeight'} - 1)
+  ||   $self->{'separate_rows'} && $self->{':lineOnPage'} + @{$self->{':rowLines'}} < $self->{'page_height'} - 1)
   && !$self->{':separatingAdded'}) {
     push(@{$self->{':rowLines'}}, $self->_cutOrWrapLine($self->{':separatingLine'}));
     $self->{':separatingAdded'} = TRUE;
@@ -341,13 +340,13 @@ sub _getNextLines {                                         # Provides next line
 sub _getNextRow {                                           # Takes over next row
   my ($self) = @_;
 
-  if ($self->{'endOfTable'}                                 # End of table already reached or being reached just now
+  if ($self->{'end_of_table'}                               # End of table already reached or being reached just now
   ||  ref($self->{'rows'}) eq 'ARRAY' && !$self->_getNextRowFromArray()
   ||  ref($self->{'rows'}) eq 'CODE'  && !$self->_getNextRowFromCallback()) {
     $self->{':rowBuffer'} = [];
   }
   else {
-    $self->{'currentRow'}++;
+    $self->{'current_row'}++;
   }
 
   return $self->{':rowBuffer'};
@@ -356,22 +355,22 @@ sub _getNextRow {                                           # Takes over next ro
 sub _getNextRowFromArray {                                  # Takes over next row from array
   my ($self) = @_;
 
-  my $currentRow = $self->{'currentRow'};
+  my $current_row = $self->{'current_row'};
 
-  $self->{':endOfChunk'} = $currentRow == $#{$self->{'rows'}};
+  $self->{':endOfChunk'} = $current_row == $#{$self->{'rows'}};
 
-  if ($currentRow > $#{$self->{'rows'}}) {
-    if ($self->{'broadRow'} != SPLIT || $self->{':splitOffset'} + $self->{'tableWidth'} >= $self->{':totalWidth'}) {
-      $self->{'endOfTable'} = TRUE;
+  if ($current_row > $#{$self->{'rows'}}) {
+    if ($self->{'broad_row'} != SPLIT || $self->{':splitOffset'} + $self->{'table_width'} >= $self->{':totalWidth'}) {
+      $self->{'end_of_table'} = TRUE;
       return FALSE;
     }
 
-    $self->{'currentRow'}    = $currentRow = 0;
-    $self->{':splitOffset'} += $self->{'tableWidth'};
+    $self->{'current_row'}   = $current_row = 0;
+    $self->{':splitOffset'} += $self->{'table_width'};
   }
 
-  $self->{':rowBuffer'} = $self->{'rows'}[$currentRow];
-  $self->{'endOfTable'} = FALSE;
+  $self->{':rowBuffer'} = $self->{'rows'}[$current_row];
+  $self->{'end_of_table'} = FALSE;
 
   return TRUE;
 }
@@ -383,22 +382,22 @@ sub _getNextRowFromCallback {                               # Takes over next ro
 
   unless (defined($self->{':numberOfColumns'})) {
     $self->{':numberOfColumns'} = ref($row) eq 'ARRAY' ? @$row : 0;
-    die("Row $self->{'currentRow'}: not an array reference") if ref($row) ne 'ARRAY';
+    die("Row $self->{'current_row'}: not an array reference") if ref($row) ne 'ARRAY';
     $self->_validateForCallback()->_setDefaults()->_init();
   }
 
   unless (defined($row)) {
-    $self->{':endOfChunk'} = $self->{'endOfTable'} = TRUE;
+    $self->{':endOfChunk'} = $self->{'end_of_table'} = TRUE;
     return FALSE;
   }
 
   my $numberOfColumns = $self->{':numberOfColumns'};
 
-  die("Row $self->{'currentRow'}: not an array reference") if ref($row) ne 'ARRAY';
-  die("Row $self->{'currentRow'}: wrong number of elements (", scalar(@$row), " instead of $numberOfColumns)")
+  die("Row $self->{'current_row'}: not an array reference") if ref($row) ne 'ARRAY';
+  die("Row $self->{'current_row'}: wrong number of elements (", scalar(@$row), " instead of $numberOfColumns)")
     if scalar(@$row) != $numberOfColumns;
   foreach (0 .. $numberOfColumns - 1) {
-    die("Row $self->{'currentRow'}: element No. $_ is ", ref($row->[$_]), ' not a scalar') if ref($row->[$_]);
+    die("Row $self->{'current_row'}: element No. $_ is ", ref($row->[$_]), ' not a scalar') if ref($row->[$_]);
   }
 
   $self->{':rowBuffer'} = _stripTrailingBlanks($row);
@@ -409,42 +408,42 @@ sub _getNextRowFromCallback {                               # Takes over next ro
 sub _init {                                                 # Set remaining attributes during object instantiating
   my ($self) = @_;
 
-  $self->{'pageHeight'} ||= BIG_INT;
-  $self->{'tableWidth'} ||= BIG_INT;
+  $self->{'page_height'} ||= BIG_INT;
+  $self->{'table_width'} ||= BIG_INT;
 
-  $self->{'pad'} = [($self->{'pad'}) x max(scalar(@{$self->{'columnWidth'}}), 1)] unless ref($self->{'pad'});
+  $self->{'pad'} = [($self->{'pad'}) x max(scalar(@{$self->{'column_width'}}), 1)] unless ref($self->{'pad'});
 
   die(
-    "Table width ($self->{'tableWidth'}) is lower than the width of the narrowest possible column i.e. 1 character, ",
+    "Table width ($self->{'table_width'}) is lower than the width of the narrowest possible column i.e. 1 character, ",
     'left-side column separator, and the lowest left-side padding (', min(@{$self->{'pad'}}), ')'
-  ) if $self->{'tableWidth'} < 1 + 1 + min(@{$self->{'pad'}});
+  ) if $self->{'table_width'} < 1 + 1 + min(@{$self->{'pad'}});
 
-  $self->{'columnWidth'} = [map { $self->{'columnWidth'}[$_] == ADJUST ? $self->_maxColumnWidth($_)
-                                                                       : $self->{'columnWidth'}[$_] }
-                            0 .. $#{$self->{'columnWidth'}}];
+  $self->{'column_width'} = [map { $self->{'column_width'}[$_] == ADJUST ? $self->_maxColumnWidth($_)
+                                                                         : $self->{'column_width'}[$_] }
+                            0 .. $#{$self->{'column_width'}}];
 
   $self->_setLineFormat();
-  $self->{':headerLines'} = $self->_prepareRow($self->{'header'}, $self->{'broadHeader'});
+  $self->{':headerLines'} = $self->_prepareRow($self->{'header'}, $self->{'broad_header'});
   if (@{$self->{':headerLines'}}) {
     unshift(@{$self->{':headerLines'}}, $self->{':separatingLine'});
     push   (@{$self->{':headerLines'}}, $self->{':separatingLine'});
   }
 
-  $self->{':linesPerRow'}  = $self->{'broadRow'} == WRAP
-                           ? ceil(length($self->{':separatingLine'}) / $self->{'tableWidth'})
+  $self->{':linesPerRow'}  = $self->{'broad_row'} == WRAP
+                           ? ceil(length($self->{':separatingLine'}) / $self->{'table_width'})
                            : 1;
   my $headerHeight         = @{$self->{':headerLines'}} * $self->{':linesPerRow'};
   $self->{':linesPerPage'} = $headerHeight
-                           + floor(($self->{'pageHeight'} - $headerHeight) / $self->{':linesPerRow'})
+                           + floor(($self->{'page_height'} - $headerHeight) / $self->{':linesPerRow'})
                            * $self->{':linesPerRow'};
 
   if (@{$self->{':headerLines'}}) {                         # At least one row or one separating line under the header
-    my $pageHeight = $headerHeight + $self->{':linesPerRow'};
-    die("Page height ($self->{'pageHeight'}) is lower than the minimum possible page height ($pageHeight)")
-      if $self->{'pageHeight'} < $pageHeight;
+    my $page_height = $headerHeight + $self->{':linesPerRow'};
+    die("Page height ($self->{'page_height'}) is lower than the minimum possible page height ($page_height)")
+      if $self->{'page_height'} < $page_height;
   }
 
-  $self->{'currentRow'} = 0;
+  $self->{'current_row'} = 0;
 
   return $self;
 }
@@ -554,25 +553,25 @@ sub _setDefaults {                                          # Set default attrib
 sub _setLineFormat {
   my ($self) = @_;
 
-  my $tableWidth = 1;
+  my $table_width = 1;
 
   foreach my $columnNo (0 .. $self->{':numberOfColumns'} - 1) {
-    my $columnWidth = $self->{'columnWidth'}[$columnNo];
-    if ($self->{'collapse'}[$columnNo] && !$columnWidth) {
+    my $column_width = $self->{'column_width'}[$columnNo];
+    if ($self->{'collapse'}[$columnNo] && !$column_width) {
       $self->{':lineFormat'} .= '%s';
     }
     else {
       my $pad = $self->{'pad'}[$columnNo];
-      $self->{':lineFormat'}     .= ' ' x  $pad . '%-' . $columnWidth . 's' . ' ' x $pad  . '|';
-      $self->{':separatingLine'} .= '-' x ($pad +        $columnWidth +             $pad) . '+';
-      $tableWidth                +=        $pad +        $columnWidth +             $pad  + 1;
+      $self->{':lineFormat'}     .= ' ' x  $pad . '%-' . $column_width . 's' . ' ' x $pad  . '|';
+      $self->{':separatingLine'} .= '-' x ($pad +        $column_width +             $pad) . '+';
+      $table_width               +=        $pad +        $column_width +             $pad  + 1;
     }
 
-    last if $self->{'broadRow'} == CUT && $tableWidth >= $self->{'tableWidth'};
+    last if $self->{'broad_row'} == CUT && $table_width >= $self->{'table_width'};
   }
 
-  $self->{':totalWidth'} = $tableWidth;
-  $self->{'currentRow'} = 0 if $tableWidth == 1;            # This table has no content
+  $self->{':totalWidth'} = $table_width;
+  $self->{'current_row'} = 0 if $table_width == 1;          # This table has no content
 
   return $self;
 }
